@@ -305,7 +305,10 @@ static void hevc_dec_get_vui_info(v4l2_dec_inst *h,
       dec_info->colour_description_present_flag;
   h->dec_info.matrix_coefficients = dec_info->matrix_coefficients;
   h->dec_info.colour_primaries = dec_info->colour_primaries;
-  h->dec_info.transfer_characteristics = dec_info->transfer_characteristics;
+  if (dec_info->trc_status == 0 || dec_info->trc_status == 2)
+    h->dec_info.transfer_characteristics = dec_info->preferred_transfer_characteristics;
+  else
+    h->dec_info.transfer_characteristics = dec_info->transfer_characteristics;
   h->dec_info.video_range = dec_info->video_range;
 }
 
