@@ -367,20 +367,13 @@ v4l2_inst_dec_event mpeg4_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
           goto end;
         }
         h->dec_pic_id++;
-#ifdef NXP_TIMESTAMP_MANAGER
-        h->consumed_len += dec_input.data_len - dec_output.data_left;
-
         re_dec_event = DEC_PIC_DECODED_EVENT;
         goto update_input;
-#endif
-        break;
+        //break;
 
       case MP4DEC_PIC_CONSUMED:
-#ifdef NXP_TIMESTAMP_MANAGER
-        h->consumed_len += dec_input.data_len - dec_output.data_left;
-        re_dec_event = DEC_DECODING_FAILED_EVENT;
+        re_dec_event = DEC_DECODING_ERROR_EVENT;
         goto update_input;
-#endif
       case MP4DEC_STRM_PROCESSED:
       case MP4DEC_NONREF_PIC_SKIPPED:
       case MP4DEC_VOS_END:
@@ -390,7 +383,9 @@ v4l2_inst_dec_event mpeg4_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
       case MP4DEC_PARAM_ERROR:
       case MP4DEC_STRM_ERROR:
         if (dec_output.data_left == dec_input.data_len) {
+          re_dec_event = DEC_DECODING_ERROR_EVENT;
           in_mem->logical_size = 0;
+          h->consumed_len += dec_input.data_len;
           goto end;
         }
         // dec_output.data_left = 0;
@@ -409,8 +404,6 @@ v4l2_inst_dec_event mpeg4_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
 
         if (mpeg4_dec_check_res_change(h, &dec_info, &hbuf) != 0) {
           re_dec_event = DEC_SOURCE_CHANGE_EVENT;
-          h->consumed_len += dec_input.data_len - dec_output.data_left;
-
           goto update_input;
         }
         if (h->dec_info.needed_dpb_nums > h->existed_dpb_nums) {
@@ -480,6 +473,7 @@ error:
     goto end;
   }
 update_input:
+  h->consumed_len += dec_input.data_len - dec_output.data_left;
   mpeg4_update_input(in_mem, &dec_input, &dec_output);
 
 end:
