@@ -425,7 +425,6 @@ v4l2_inst_dec_event vc1l_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
 
         if (vc1_dec_check_res_change(h, &dec_info, &hbuf) != 0) {
           re_dec_event = DEC_SOURCE_CHANGE_EVENT;
-          h->consumed_len += dec_input.stream_size - dec_output.data_left;
           goto update_input;
         }
         if (h->dec_info.needed_dpb_nums > h->existed_dpb_nums) {
@@ -449,20 +448,14 @@ v4l2_inst_dec_event vc1l_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
           goto end;
         }
         h->dec_pic_id++;
-#ifdef NXP_TIMESTAMP_MANAGER
-        h->consumed_len += dec_input.stream_size - dec_output.data_left;
         re_dec_event = DEC_PIC_DECODED_EVENT;
         goto update_input;
-#endif
-        break;
+        //break;
 
       case VC1DEC_PIC_CONSUMED:
-#ifdef NXP_TIMESTAMP_MANAGER
-        h->consumed_len += dec_input.stream_size - dec_output.data_left;
-        re_dec_event = DEC_DECODING_FAILED_EVENT;
+        re_dec_event = DEC_DECODING_ERROR_EVENT;
         goto update_input;
-#endif
-        break;
+        //break;
 
       case VC1DEC_END_OF_SEQ:
         dec_input.stream_size = 0;
@@ -525,6 +518,7 @@ error:
   }
 
 update_input:
+  h->consumed_len += dec_input.stream_size - dec_output.data_left;
   vc1l_update_input(in_mem, &dec_input, &dec_output);
 
 end:
@@ -690,7 +684,6 @@ v4l2_inst_dec_event vc1g_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
 
         if (vc1_dec_check_res_change(h, &dec_info, &hbuf) != 0) {
           re_dec_event = DEC_SOURCE_CHANGE_EVENT;
-          h->consumed_len += dec_input.stream_size - dec_output.data_left;
           goto update_input;
         }
         if (h->dec_info.needed_dpb_nums > h->existed_dpb_nums) {
@@ -714,20 +707,14 @@ v4l2_inst_dec_event vc1g_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
           goto end;
         }
         h->dec_pic_id++;
-#ifdef NXP_TIMESTAMP_MANAGER
-        h->consumed_len += dec_input.stream_size - dec_output.data_left;
         re_dec_event = DEC_PIC_DECODED_EVENT;
         goto update_input;
-#endif
-        break;
+        //break;
 
       case VC1DEC_PIC_CONSUMED:
-#ifdef NXP_TIMESTAMP_MANAGER
-        h->consumed_len += dec_input.stream_size - dec_output.data_left;
-        re_dec_event = DEC_DECODING_FAILED_EVENT;
+        re_dec_event = DEC_DECODING_ERROR_EVENT;
         goto update_input;
-#endif
-        break;
+        //break;
 
       case VC1DEC_END_OF_SEQ:
         dec_input.stream_size = 0;
@@ -789,6 +776,7 @@ error:
     goto end;
   }
 update_input:
+  h->consumed_len += dec_input.stream_size - dec_output.data_left;
   vc1g_update_input(in_mem, &dec_input, &dec_output);
 
 end:
