@@ -78,7 +78,6 @@ static void handle_encoder_err(v4l2_enc_inst *h, vsi_v4l2_msg *v4l2_msg,
   send_enc_orphan_msg(v4l2_msg, io_buf->inbufidx, io_buf->outbufidx,
                       stream_size, ret);
   h->func.close(h);
-  h->inst = NULL;
 }
 
 void check_if_cbr_bitrate_changed(v4l2_enc_inst *h,
@@ -261,17 +260,11 @@ int32_t enc_cmd_processor(v4l2_enc_inst *h, struct vsi_v4l2_msg *v4l2_msg) {
       {
         HANTRO_LOG(HANTRO_LEVEL_INFO, "Has Param when streamon.\n");
       }
-      if (v4l2_msg->param_type == 0 &&
-        (h->state == ENC_ENCODING || h->state == ENC_PAIRING || h->state == ENC_DRAIN)) {
-        HANTRO_LOG(HANTRO_LEVEL_DEBUG, "ignore stream on because current state is %d.\n", h->state);
-        break;
-      }
       h->state = ENC_INIT;
       h->already_streamon = 1;
       h->already_command_stop = h->drain_input_num_total =
           h->drain_input_num_now = 0;
-      if (v4l2_msg->param_type)
-        h->flushbuf = 1;
+      h->flushbuf = 1;
       break;
 
     case V4L2_DAEMON_VIDIOC_CMD_STOP:  // this is for flush.
@@ -281,11 +274,29 @@ int32_t enc_cmd_processor(v4l2_enc_inst *h, struct vsi_v4l2_msg *v4l2_msg) {
       h->state = ENC_DRAIN;
       break;
 
-    case V4L2_DAEMON_VIDIOC_STREAMOFF:
+    case V4L2_DAEMON_VIDIOC_DESTROY_ENC:
     case V4L2_DAEMON_VIDIOC_EXIT:
       h->state = ENC_RELEASED;
       break;
 
+    case V4L2_DAEMON_VIDIOC_ENC_RESET:
+      h->func.reset_enc(h);
+      h->state = ENC_STOPPED;
+    break;
+
+    case V4L2_DAEMON_VIDIOC_STREAMOFF_OUTPUT:
+      bufferlist_flush(h->bufferlist_input);
+      send_cmd_orphan_msg(h->instance_id, V4L2_DAEMON_VIDIOC_STREAMOFF_OUTPUT_DONE);
+      h->state = ENC_STOPPED;
+      break;
+
+    case V4L2_DAEMON_VIDIOC_STREAMOFF_CAPTURE:
+      bufferlist_flush(h->bufferlist_output);
+      h->func.reset_enc(h);
+      send_cmd_orphan_msg(h->instance_id, V4L2_DAEMON_VIDIOC_STREAMOFF_CAPTURE_DONE);
+      h->state = ENC_STOPPED;
+      break;
+
     case V4L2_DAEMON_VIDIOC_FAKE:
       break;
     default:
@@ -418,15 +429,6 @@ v4l2_inst_state enc_state_processor(v4l2_enc_inst *h, vsi_v4l2_msg *v4l2_msg) {
 
     case ENC_ENCODING:
       /*encoding step 1: find next picture, get buffer and set gop structure.*/
-      if(v4l2_msg->cmd_id == V4L2_DAEMON_VIDIOC_ENC_RESET) {
-          if (h->bufferlist_input) bufferlist_flush(h->bufferlist_input);
-          if (h->bufferlist_output) bufferlist_flush(h->bufferlist_output);
-          if (h->bufferlist_reorder) bufferlist_flush(h->bufferlist_reorder);
-          h->input_frame_cnt = 0;
-          h->func.reset_enc(h);
-          return ENC_ENCODING;
-      }
-
       h->func.find_next_pic(h, &p_buffer, &list_num);
       if (p_buffer == NULL) {
         break;
@@ -448,6 +450,7 @@ v4l2_inst_state enc_state_processor(v4l2_enc_inst *h, vsi_v4l2_msg *v4l2_msg) {
 
       if (h->cbr_bitrate_change == 1 && h->next_pic_type == 0) {
         h->func.end(h, &size_header_plus_i);
+        h->func.close(h);
         enc_unmap_io_buff(h, io_buf);
         h->cbr_bitrate_change = 0;
         h->state = ENC_INIT;
@@ -612,18 +615,12 @@ v4l2_inst_state enc_state_processor(v4l2_enc_inst *h, vsi_v4l2_msg *v4l2_msg) {
                    "Encoded frames: %ld, encode fps: %0.2f\n", h->total_frames,
                    ((double)h->total_frames * 1000000) / h->total_time);
       }
-      if (h->inst) {
-        h->func.close(h);
-        h->inst = NULL;
-        h->state = ENC_NONE;
-      }
+      h->func.close(h);
+      h->state = ENC_NONE;
       return ENC_STOPPED;
     case ENC_RELEASED:
-      if (h->inst) {
-        h->func.close(h);
-        h->inst = NULL;
-        h->state = ENC_NONE;
-      }
+      h->func.close(h);
+      h->state = ENC_NONE;
       return ENC_RELEASED;
     default:
       break;
@@ -632,7 +629,6 @@ v4l2_inst_state enc_state_processor(v4l2_enc_inst *h, vsi_v4l2_msg *v4l2_msg) {
 
 _label_enc_stopped:
   h->func.close(h);
-  h->inst = NULL;
   return ENC_STOPPED;
 }
 
