@@ -414,7 +414,7 @@ static int set_rate_control_h264(v4l2_enc_inst *h,
   if (enc_params->specific.enc_h26x_cmd.picRc == 0) rcCfg->hrd = 0;
 
   enc_params->specific.enc_h26x_cmd.cpbSize = -1;
-  if (enc_params->specific.enc_h26x_cmd.cpbSize != -1)
+  if (enc_params->specific.enc_h26x_cmd.cpbSize > 0)
     rcCfg->hrdCpbSize = enc_params->specific.enc_h26x_cmd.cpbSize;
   else {//cpbSize default value.
     int32_t levelIdx = getLevelIdxH264(cfg->level);
@@ -744,6 +744,8 @@ static int set_coding_control_h264(v4l2_enc_inst *h,
       codingCfg->roi2DeltaQp == 0)
     codingCfg->roi2Area.enable = 0;
 
+  codingCfg->chroma_qp_offset = enc_params->specific.enc_h26x_cmd.chromaQpOffset;
+
   if ((ret = H264EncSetCodingCtrl(
             h->inst, &h264_params->video_coding_ctrl)) != H264ENC_OK) {
     HANTRO_LOG(HANTRO_LEVEL_ERROR, "H264EncSetPreProcessing error.\n");
