@@ -1561,7 +1561,7 @@ static void get_rate_control_from_cmd_h2(v4l2_enc_inst *h,
   if (enc_params->specific.enc_h26x_cmd.hrdConformance != -1)
     rcCfg->hrd = enc_params->specific.enc_h26x_cmd.hrdConformance;
   if (enc_params->specific.enc_h26x_cmd.picRc == 0) rcCfg->hrd = 0;
-  if (enc_params->specific.enc_h26x_cmd.cpbSize != -1)
+  if (enc_params->specific.enc_h26x_cmd.cpbSize > 0)
     rcCfg->hrdCpbSize = enc_params->specific.enc_h26x_cmd.cpbSize;
   else {//cpbSize default value.
     int32_t levelIdx;
